%==============================================================================
% destufba - classe de documento com padres para documentos do Departamento de 
%            Estatistica da UFBA
%
% Este documento foi baseado no documento construdo pelo UFRGS TeX Users Group,
% Grupo de Usurios TeX da UFRGS, UNIPAMPA e adaptado para atender ao manual de normalizao
% do Departamento de Estatstica da UFBA, pelo Prof. Jalmar Manuel Farfan Carrasco.
%
% Este arquivo  distribudo por meio da licena GNU Public License.
%
% No nos responsabilizamos por manter este documento. Sugestes e atualizaes
% podem ser enviadas para carrasco.jalmar@ufba.br.
%
%==============================================================================


%==============================================================================
%
% Identificao deste documento
%
%==============================================================================

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{destufba}[2019/08/09 Formatacao de documentos para o DE da UFBA]

%==============================================================================
%
% Informaes sobre cursos e titulaes
%
%==============================================================================

\newcommand{\UFBA}{Universidade Federal da Bahia}

\newcommand{\course}[1]{\gdef\@course{#1}}                  % nome do curso, sem modalidade - no caso de ps-graduao, com nome completo
\newcommand{\modalidade}[1]{\gdef\@modalidade{#1}}          % somente para a graduao (Licenciatura, Bacharelado, Curso Superior de Tecnologia)
\newcommand{\campus}[1]{\gdef\@campus{#1}}                  % nome do Campus
\newcommand{\advisorname}{Orientador}%
\newcommand{\coadvisorname}{Co-orientador}%


%==============================================================================
%
% Tipos de documentos suportados por este modelo
%
%==============================================================================


\DeclareOption{tcc}{%
    \newcommand{\titlepagespecificinfo}{\tccspecificinfo}
    \def\@cipspecificinfo{\tccname\ (Graduao)}
    \def\textapproval{\tccapproval}
}
\DeclareOption{espec}{%
    \newcommand{\titlepagespecificinfo}{\especspecificinfo}
    \def\@cipspecificinfo{\especname\ (Especializao)}
    \def\textapproval{\especapproval}
}
\DeclareOption{mestrado}{%
    \newcommand{\titlepagespecificinfo}{\dissspecificinfo}
    \def\@cipspecificinfo{\dissname\ (Mestrado)}
    \def\textapproval{\dissapproval}
}

%==============================================================================
%
% Outros pacotes locais importados
%
%==============================================================================

\newcommand{\destufba@novodoc}[1]{\DeclareOption{#1}{\AtEndOfClass{\input{#1.def}}}}

%==============================================================================
%
% Definies para os cursos de graduao
%
%==============================================================================

\DeclareOption{est}{%
  \course{Estatstica}
  \modalidade{Bacharelado}
  \campus{Salvador}
	\providecommand{\titulacaoEm}{Bacharel em Estatstica}
}

%==============================================================================
%
% Definies para os cursos de ps-graduao
%
%==============================================================================

\DeclareOption{ppgest}{%
    \course{Programa de Ps-Graduao em Matemtica}
    \providecommand{\areacourse}{Estatstica}
    \providecommand{\titulacaoEm}{Matemtica (rea: Estatstica)}
    \campus{Salvador}
}

\DeclareOption{ppgcdbd}{%
    \course{Programa de Ps-Graduao em Cincia de Dados e Big Data}
    \providecommand{\areacourse}{}
    \providecommand{\titulacaoEm}{Especialista em Cincia de Dados e Big Data}
    \campus{Salvador}
}

%==============================================================================
%
% Outros documentos necessrios para a produo dos documentos
%
%==============================================================================

\destufba@novodoc{formais} 						% pacote para definies formais - definies, teoremas, provas, etc.

%==============================================================================
%
% Declaraes de lngua e estrutura base dos documentos
%
%==============================================================================

\DeclareOption{english}{\@englishtrue\OptionNotUsed}\newif\if@english
\DeclareOption{noabntcite}{\@noabntcitetrue\OptionNotUsed}\newif\if@noabntcite
\DeclareOption{oneside}{\AtEndOfClass{\@twosidefalse}\OptionNotUsed}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\ProcessOptions\relax


%==============================================================================
%
% Incluso de opes da classe 'report' e outros pacotes e arquivos
%
%==============================================================================

\LoadClass[12pt,a4paper,twoside]{report}

\RequirePackage{xspace}
\RequirePackage{keyval}
\RequirePackage{fixltx2e}

\RequirePackage[english,brazilian]{babel}
\input{brazilian.babel}
\input{english.babel}
\if@english
        \selectlanguage{english}
        \AtBeginDocument{\selectlanguage{english}}
\fi
\RequirePackage{lastpage}
\RequirePackage{indentfirst}
%\RequirePackage{unipampadefs}
\RequirePackage{setspace}
\RequirePackage{ccaption}
\RequirePackage{caption}
\RequirePackage{titlesec}
\RequirePackage{fancyhdr}
\RequirePackage[usenames,dvipsnames,svgnames,table]{xcolor}
\RequirePackage[tocindentauto,tocfullflat]{tocstyle}
\settocfeature[toc][0]{entryhook}{\bfseries\uppercase}
\settocfeature[toc][1]{entryhook}{\bfseries}
\settocstylefeature{pagenumberbox}{\pnbox}
\settocfeature[lof][1]{entryhook}{\figurename\hspace{0.2em}} % valor calculado no olho. Deveria ser um espao de tamanho fixo, mas ~ tem tamanho varivel
\settocfeature[lot][1]{entryhook}{\tablename\hspace{0.2em}}

\RequirePackage[%
        bookmarksnumbered=true,
        breaklinks=true,
        unicode=true,
%
        colorlinks=true,
        anchorcolor=black,
        citecolor=black,
        filecolor=black,
        linkcolor=black,
        urlcolor=black
]{hyperref}[2009/10/09]
\RequirePackage[all]{hypcap}

\ifxetex
  \usepackage{tgtermes}
\else
  \usepackage{times}              % pacote para usar fonte Adobe Times
  \RequirePackage[T1]{fontenc}
\fi

\if@noabntcite
\else
\RequirePackage[
    % Habilita o uso de citaes no formato autor-data.
	alf,
	% O modelo da UFRGS requer que os títulos dos trabalhos estejam em negrito.
    % Isso é opcional na norma ABNT (que permite que seja usado itálico) e
    % não é o padrão do abntex2.
    abnt-emphasize=bf
]{abntex2cite}
\fi

% espaamento entre as linhas
\newcommand{\setlinespacing}{\setstretch{1.415}}
\setlinespacing

% estes valores esto no segundo pargrafo da introduo dos documentos da biblioteca e, portanto, estão corretos
% a numeração deve estar a 20mm do topo, logo headsep=30mm-20mm = 10mm
\RequirePackage[top=30mm,bottom=20mm,left=30mm,right=30mm,headsep=10mm]{geometry}
%\RequirePackage{calc}

\vfuzz=30pt % prevent "overfull \vbox while \output is active" warning

%==============================================================================
% Margens do texto
%==============================================================================

% indentação dos parágrafos (medido no olho)
\setlength{\parindent}{3em}
\AtBeginDocument{\setlength{\parskip}{0mm}}

%==============================================================================
% Numeração das páginas
%==============================================================================
\def\ps@iiufrgs{
        \let\@oddfoot\@empty
        \let\@evenfoot\@empty
        \def\@evenhead{{\small\thepage}}
        \def\@oddhead{\hspace*{\fill}{\small\thepage}}
}
\pagestyle{empty}
\let\ps@plain\ps@empty

%==============================================================================
% Definio de autor(es), orientador e co-orientador
%==============================================================================
\newcounter{ii@authorcount}
\renewcommand{\author}[2]{
        \addtocounter{ii@authorcount}{1}
        \expandafter\gdef\csname @author\alph{ii@authorcount}last\endcsname{#1}
        \expandafter\gdef\csname @author\alph{ii@authorcount}first\endcsname{#2}
        \expandafter\gdef\csname @author\alph{ii@authorcount}\endcsname{#2 #1}
}
\DeclareRobustCommand{\advisor}[3][]{
        \gdef\@advisorlast{#2}
        \gdef\@advisorfirst{#3}
        \gdef\@advisor{#1~#3 #2}
}
\DeclareRobustCommand{\coadvisor}[3][]{
        \gdef\@coadvisorlast{#2}
        \gdef\@coadvisorfirst{#3}
        \gdef\@coadvisor{#1~#3 #2}
}

%==============================================================================
% Definio dos membros da banca e suas instituies
%==============================================================================
\newcounter{ii@bancacount}
\newcounter{ii@instcount}

\newcommand{\banca}[3][]{
        \addtocounter{ii@bancacount}{1}
        \expandafter\gdef\csname @banca\alph{ii@bancacount}last\endcsname{#1}
        \expandafter\gdef\csname @banca\alph{ii@bancacount}first\endcsname{#2}
        \expandafter\gdef\csname @banca\alph{ii@bancacount}\endcsname{#1 #3 #2}
}

\newcommand{\inst}[1]{
        \addtocounter{ii@instcount}{1}
        \expandafter\gdef\csname @inst\alph{ii@instcount}\endcsname{#1}
}

%==============================================================================
% Definio das palavras-chave (max. 10)
%==============================================================================
\newcounter{kwcounter}
\newcommand{\keyword}[1]{
        \addtocounter{kwcounter}{1}
        \expandafter\gdef\csname keyw\alph{kwcounter}\endcsname{#1}
}
\newcommand{\@cipkw}{%
        \@ifundefined{keywa}{}{1.~\expandafter\MakeUppercase\keywa\@. }%
        \@ifundefined{keywb}{}{2.~\expandafter\MakeUppercase\keywb\@. }%
        \@ifundefined{keywc}{}{3.~\expandafter\MakeUppercase\keywc\@. }%
        \@ifundefined{keywd}{}{4.~\expandafter\MakeUppercase\keywd\@. }%
        \@ifundefined{keywe}{}{5.~\expandafter\MakeUppercase\keywe\@. }%
        \@ifundefined{keywf}{}{6.~\expandafter\MakeUppercase\keywf\@. }%
        \@ifundefined{keywg}{}{7.~\expandafter\MakeUppercase\keywg\@. }%
        \@ifundefined{keywh}{}{8.~\expandafter\MakeUppercase\keywh\@. }%
        \@ifundefined{keywi}{}{9.~\expandafter\MakeUppercase\keywi\@. }%
        \@ifundefined{keywj}{}{10.~\expandafter\MakeUppercase\keywj\@. }%
}
\newcommand{\@abstractkw}{%
        \@ifundefined{keywa}{}{\expandafter\MakeUppercase\keywa}%
        \@ifundefined{keywb}{}{. \keywb}%
        \@ifundefined{keywc}{}{. \keywc}%
        \@ifundefined{keywd}{}{. \keywd}%
        \@ifundefined{keywe}{}{. \keywe}%
        \@ifundefined{keywf}{}{. \keywf}%
        \@ifundefined{keywg}{}{. \keywg}%
        \@ifundefined{keywh}{}{. \keywh}%
        \@ifundefined{keywi}{}{. \keywi}%
        \@ifundefined{keywj}{}{. \keywj}%
}

%==============================================================================
% Redefinio da data (para ter ms e ano separados)
%==============================================================================
\renewcommand{\date}[2]{
        \gdef\@publmonth{#1}
        \gdef\@publyear{#2}%
}
\date{\monthname}{\number\year}

%==============================================================================
% Definio padro da folha de rosto.
% Os dados especficos do tipo de trabalho (dissertao) so
% informados definindo-se o comando \titlepagespecificinfo. Veja os
% arquivos .def includos com a classe.
%==============================================================================
\newlength{\titlepagewinwidth}\setlength{\titlepagewinwidth}{95mm}
\newlength{\titlepagewinheight}\setlength{\titlepagewinheight}{64mm}
\newlength{\titlepagewinvoffset}\setlength{\titlepagewinvoffset}{112mm}
\newlength{\approvalpagewinvoffset}\setlength{\approvalpagewinvoffset}{30mm}
\newlength{\bancapagewinvoffset}\setlength{\bancapagewinvoffset}{40mm}

\newcommand{\location}[2]{
        \gdef\@city{#1}
        \gdef\@state{#2}
}
\renewcommand{\maketitle}{%
  \setstretch{0.92}
  \hypersetup{%
    pdftitle={\@title},%
    pdfauthor={%
      \@authora%
      \@ifundefined{@authorb}{}{, \@authorb}%
      \@ifundefined{@authorc}{}{, \@authorc}%
      \@ifundefined{@authord}{}{, \@authord}%
    },%
    pdfkeywords={%
      \@ifundefined{keywa}{}{\keywa}%
      \@ifundefined{keywb}{}{. \keywb}%
      \@ifundefined{keywc}{}{. \keywc}%
      \@ifundefined{keywd}{}{. \keywd}%
      \@ifundefined{keywe}{}{. \keywe}%
      \@ifundefined{keywf}{}{. \keywf}%
      \@ifundefined{keywg}{}{. \keywg}%
      \@ifundefined{keywh}{}{. \keywh}%
      \@ifundefined{keywi}{}{. \keywi}%
      \@ifundefined{keywj}{}{. \keywj}%
    }%
  }%
  \begin{titlepage}
      \thetitlepage
  \end{titlepage}%
  \clearpage
  \setcounter{page}{2}%
  %\@ifundefined{@cipspecificinfo}{\@makenominatapage}{\@makecippage}
  \@ifundefined{@cipspecificinfo}{}{\@makecippage}
  \setlinespacing
  \@ifundefined{@bancaa}{}{\folhadeaprovacao}%
}
\newcommand{\thetitlepage}{%
  \noindent\@topbox\\
  %\vspace{5.9ex}\\
  \vfill
  \centerline{\textbf{\@city}}
  \centerline{\textbf{\ii@date}}
  \vspace{8mm}
  \clearpage
  \noindent\@authorbox\\
  \vspace{5.9ex}\\
  \setstretch{0.95}
  \@ifundefined{titlepagespecificinfo}{}{
    \hspace*{\fill}\makebox[.56\textwidth][l]{%
      \parbox[t]{0.56\textwidth}{\lefthyphenmin=64\titlepagespecificinfo}%
    }%
    \vspace{5.5ex}\\
  }
  \@ifundefined{@advisor}{}{
    \hspace*{\fill}\makebox[.56\textwidth][l]{%
      \parbox[t]{0.56\textwidth}{\raggedright\lefthyphenmin=64\titlepageadvisorinfo}%
    }%
  }
  \vfill
  \centerline{\textbf{\@city}}
  \centerline{\textbf{\ii@date}}
  \vspace{8mm}
}
\def\@topbox{%
        \parbox[t]{\textwidth}{%
                \centering%
                \vbox to \titlepagewinvoffset{%
                        \titlepagetopinfo\vfill\@winbox
                }
        }
}
\def\@authorbox{%
        \parbox[t]{\textwidth}{%
                \centering%
                \vbox to \titlepagewinvoffset{%
                        \titlepageauthorinfo\vfill\@authorwinbox
                }
        }
}
\def\@authorwinbox{%
%       \fbox{
        \parbox[b]{\titlepagewinwidth}{%
        \centering\vbox to \titlepagewinheight{%
                \vspace*{5ex}
                {\large\MakeUppercase{\textbf{\@title}}\par}
                \vfill
        }%
       }%
}
\def\@winbox{%
%       \fbox{
        \parbox[b]{\titlepagewinwidth}{%
        \centering\vbox to \titlepagewinheight{%
                \vspace*{5ex}
                \MakeUppercase{\textbf{\@authora}}\\
                \@ifundefined{@authorb}{}{\MakeUppercase{\@authorb}\\}%
                \@ifundefined{@authorc}{}{\MakeUppercase{\@authorc}\\}%
                \@ifundefined{@authord}{}{\MakeUppercase{\@authord}\\}%
                \vspace{3cm}
                {\large\MakeUppercase{\textbf{\@title}}\par}
                \vfill
        }}%
%       }%
}

\newcommand{\titlepagetopinfo}{%
        \MakeUppercase{\bf\UFBA}\\
        %\MakeUppercase{Campus \@city}\\
        %\@ifundefined{@dept}{}{\MakeUppercase{\csname dept\@dept\endcsname}\\}%
        %\MakeUppercase{\@course}\\
}
\newcommand{\titlepageauthorinfo}{%
                \MakeUppercase{\textbf{\@authora}}\\
                \@ifundefined{@authorb}{}{\MakeUppercase{\@authorb}\\}%
                \@ifundefined{@authorc}{}{\MakeUppercase{\@authorc}\\}%
                \@ifundefined{@authord}{}{\MakeUppercase{\@authord}\\}%
                %\vspace{3cm}
                %{\large\textbf{\@title}\par}
}
\newcommand{\titlepageadvisorinfo}{%
        \@ifundefined{@advisor}{}{\advisorname:~\@advisorfirst\ \@advisorlast\\}%
        \@ifundefined{@coadvisor}{}{\coadvisorname:~\@coadvisorfirst\ \@coadvisorlast\\}%
}

%==============================================================================
% Definio da folha de aprovao
%==============================================================================

\newcommand{\defesa}[3]{        
        \gdef\@defday{#1}
        \gdef\@defmonth{#2}%
        \gdef\@defyear{#3}%
}

\newcommand{\folhadeaprovacao}{%
  \clearpage
  %\noindent\@approvalbox\\
  \noindent\parbox[t]{\textwidth}{%
       \centering%
       \vbox to \approvalpagewinvoffset{%
           \titlepageauthorinfo
           \vfill
           %\@approvalwinbox
           \parbox[b]{\titlepagewinwidth}{%
           %\centering\vbox to .5\titlepagewinheight{%
                \vspace*{20mm}
                {\large\MakeUppercase{\textbf{\@title}}\par}
            }
       %}
       \vspace{36pt}
       \setstretch{0.95}
       \vfill
       \@ifundefined{titlepagespecificinfo}{}{
             \hspace*{\fill}\makebox[.56\textwidth][l]{%
                 \parbox[t]{0.56\textwidth}{\lefthyphenmin=64\titlepagespecificinfo}%
             }%
             \vspace{12pt}\\
        }
				\@ifundefined{areacourse}{}{
				    \hspace*{\fill}\makebox[\textwidth][r]{%
				        \parbox[t]{0.56\textwidth}{rea de concentrao: \righthyphenmin=64\areacourse}%
				    }%
				    \vspace{18pt}\\
				}
     }
  }
  \vfill
  %\parbox[b]{.5\titlepagewinwidth}{%
  %      \centering\vbox to .5\titlepagewinheight{%
  %              \vspace*{20mm}
  %				       }%
	%}
  \noindent\@bancabox\\
}

%\def\@approvalbox{%
%        \parbox[t]{\textwidth}{%
%                \centering%
%                \vbox to \approvalpagewinvoffset{%
%                        \titlepageauthorinfo
%                        \vfill
%                        %\@approvalwinbox
%                        \parbox[b]{\titlepagewinwidth}{%
%                               \centering\vbox to .5\titlepagewinheight{%
%                                   \vspace*{20mm}
%                                   {\large\MakeUppercase{\textbf{\@title}}\par}
%                               }%
%                        }%
%                        \vspace{10mm}
%                        \setstretch{0.95}
%                        \@ifundefined{titlepagespecificinfo}{}{
%                           \hspace*{\fill}\makebox[.56\textwidth][l]{%
%                              \parbox[t]{0.56\textwidth}{\lefthyphenmin=64\titlepagespecificinfo}%
%                           }%
%                           \vspace{12pt}\\
%                        }%
%				                \@ifundefined{areacourse}{}{
%				                   \hspace*{\fill}\makebox[\textwidth][r]{%
%				                      \parbox[t]{0.56\textwidth}{rea de concentrao: \righthyphenmin=64\areacourse}%
%				                   }%
%				                   \vspace{18pt}\\
%				                }
%                        \vfill
%                }
%        }
%}
%\def\@approvalwinbox{%
        %\parbox[b]{\titlepagewinwidth}{%
        %\centering\vbox to .5\titlepagewinheight{%
                %\vspace*{20mm}
               % {\large\MakeUppercase{\textbf{\@title}}\par}
     %   }%
    %   }%
%}

\def\@bancabox{%
        \parbox[t]{\textwidth}{%
                \centering%
                \vbox to .5\textheight{%
                        \vfill
                        \@newbancawinbox
                }
        }
}

\def\@newbancawinbox{%
        %\raggedright%\framebox[.9\textwidth]{%
        
						 \centering
             \begin{minipage}{.9\textwidth}%
						    \centering
                \setstretch{0.95}
                \vspace*{0.2ex}
                \setlength{\parindent}{0em}%
                \setlength{\parskip}{1.3ex}%
                \textapproval\ \@defday\ de \@defmonth\ de \@defyear.\\
    						\vspace*{12pt}
    						Banca examinadora:\\
    						%\hspace*{\fill}
    						\begin{tabular}{p{10mm}cp{10mm}}
    						          & &\\ & &\\ & &\\ 
    						          \hline
      										&\@advisor&\\ 
      										&\advisorname&\\
      										%&\@ifundefined\instorientador{Universidade Federal do Pampa}{\@instorientador}&\\
      										\@ifundefined{@bancaa}{}{& &\\ & &\\ & &\\ \hline &\@bancaa& \\ &\@insta& \\}%
      										\@ifundefined{@bancab}{}{& &\\ & &\\ & &\\ \hline &\@bancab& \\ &\@instb& \\}%
      										\@ifundefined{@bancac}{}{& &\\ & &\\ & &\\ \hline &\@bancac& \\ &\@instc& \\}%
      										\@ifundefined{@bancad}{}{& &\\ & &\\ & &\\ \hline &\@bancad& \\ &\@instd& \\}%
      										\@ifundefined{@bancae}{}{& &\\ & &\\ & &\\ \hline &\@bancae& \\ &\@inste& \\}%
      					\end{tabular}
   							\vspace*{20mm}
								\vfill
             \end{minipage}%
             \vspace*{10mm}
}

\def\@bancawinbox{%
        \parbox[b]{\titlepagewinwidth}{%
           \centering\vbox to \titlepagewinheight{%
                \centering
    					  \noindent Dissertao defendida e aprovada em: \@defday\ de \@defmonth\ de \@defyear.\\
    						\vspace{12pt}
    						\noindent Banca examinadora:
    						%\hspace*{\fill}
    						\makebox[\textwidth][c]{%
      							\fbox{\parbox[c]{\textwidth}{%\lefthyphenmin=64%
                          \setstretch{0.95}
     										  \vspace{24pt}\@advisor\\ \advisorname \\%
      										\@ifundefined{@bancaa}{}{\ \vspace{24pt}{\@bancaa}\\}%
      										\@ifundefined{@bancab}{}{\ \vspace{24pt}{\@bancab}\\}%
      										\@ifundefined{@bancac}{}{\ \vspace{24pt}{\@bancac}\\}%
      										\@ifundefined{@bancad}{}{\ \vspace{24pt}{\@bancad}\\}%
      										\@ifundefined{@bancae}{}{\ \vspace{24pt}{\@bancae}\\}%
   							 		      \vfill
   							 		}%
        				    \vspace{20mm}}
        				}%
          }%
     }
}


%==============================================================================
% Catalogaoo na fonte (CIP) 
%==============================================================================
\newcommand{\@makecippage}{%
        \clearpage%
        \ \vfill
        \begin{center}
                %\textbf{\cipcaption}\\[2ex]
                \iiu@cipwindow
        \end{center}
        %\vfill
        %\nominata
}

\newcommand{\cutter}[1]{\gdef\@cutter{#1}}

%
% definio do quadro de catalogao bibliogrfica
%
\def\iiu@cipwindow{%
        \framebox[125mm]{%
        
        \begin{minipage}{110mm}%
                \vspace*{0.2ex}
                \setlength{\parindent}{1.5em}%
                \setlength{\parskip}{1.3ex}%
                \hspace{-12mm}\parbox[t]{5mm}{\@cutter}
                \hspace{12mm}\parbox[t]{95mm}{
                        \setlength{\parindent}{1.5em}%
                        \setlength{\parskip}{1.3ex}%
                				\noindent\@authoralast, \@authorafirst\par
                				\@title\ / \@authora.\ -- \@publmonth, \@publyear. \par
                				\pageref{LastPage}~f.: il. \par
                				\@cipspecificinfo\ -- Universidade Federal da Bahia, Campus \@campus, \@course,  \@publyear. \par
                				``Orientao: \@advisorfirst\ \@advisorlast\@ifundefined{@coadvisor}{}{; Co-orientao: \@coadvisorfirst\ \@coadvisorlast}''.\par
               					 \@cipkw I.~Ttulo.\\
                \vspace{0.2ex}}
        \end{minipage}
        }%
}

%==============================================================================
% Dedicatria
%==============================================================================

\newenvironment{dedicatoria}{\clearpage\begin{flushright}\ \vfill\begin{minipage}{.5\textwidth}}{\end{minipage}\end{flushright}}

%==============================================================================
% Epgrafe
%==============================================================================

\newenvironment{epigrafe}{\begin{dedicatoria}}{\end{dedicatoria}}

%==============================================================================
% Ajuste do sumrio
%==============================================================================
\renewcommand{\@dotsep}{0}
\newlength{\dottedspace}
\newcommand{\pnbox}[1]{\settowidth{\dottedspace}{\bfseries#1}\hb@xt@\dottedspace{#1}}

\newcommand\samepagechapter{
                    %\thispagestyle{plain}%
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}

\setcounter{tocdepth}{3}
\newif\if@aftertoc
\@aftertocfalse
\renewcommand{\tableofcontents}{%
  \chapter*{\contentsname}
  \vspace{0.4\baselineskip}
  \setstretch{0.95}
  \@starttoc{toc}\@aftertoctrue%
  % retorna o espaçamento ao seu valor original
  \setlinespacing
}
\renewcommand{\listoffigures}{%
  \chapter*{\listfigurename}
  \setstretch{0.95}
  \@starttoc{lof}%
  % retorna o espaçamento ao seu valor original
  \setlinespacing
}
\renewcommand{\listoftables}{%
  \chapter*{\listtablename}
  \setstretch{0.95}
  \@starttoc{lot}%
  % retorna o espaçamento ao seu valor original
  \setlinespacing
}

%==============================================================================
% Definição das listas de abreviaturas e siglas e de símbolos
%==============================================================================
\newenvironment{listofabbrv}[1]{
        \chapter*{\listabbrvname}
        \begin{list}{\textbf{??}}{
                \settowidth{\labelwidth}{#1}
                \setlength{\labelsep}{1em}
                \setlength{\itemindent}{0mm}
                \setlength{\leftmargin}{\labelwidth}
                \addtolength{\leftmargin}{\labelsep}
                \setlength{\rightmargin}{0mm}
                \setlength{\itemsep}{.1\baselineskip}
                \renewcommand{\makelabel}[1]{\makebox[\labelwidth][l]{##1}}
        }
}{
        \end{list}
}
\newenvironment{listofsymbols}[1]{
        \chapter*{\listsymbolname}
        \begin{list}{\textbf{??}}{
                \settowidth{\labelwidth}{#1}
                \setlength{\labelsep}{1em}
                \setlength{\itemindent}{0mm}
                \setlength{\leftmargin}{\labelwidth}
                \addtolength{\leftmargin}{\labelsep}
                \setlength{\rightmargin}{0mm}
                \setlength{\itemsep}{.1\baselineskip}
                \renewcommand{\makelabel}[1]{\makebox[\labelwidth][l]{##1}}
        }
}{
        \end{list}
}

%==============================================================================
% Resumo (abstract) e Abstract (englishabstract)
%==============================================================================
\renewenvironment{abstract}{%
        \chapter*{\abstractname}\setlength{\parindent}{0pt}
}{%
    %\par\vfill
    %\\
    \\

    \vspace{\parskip}\noindent\textbf{\keywordsname:} \@abstractkw.
}

\newenvironment{englishabstract}[1]{%
        \if@openright\cleardoublepage\else\clearpage\fi%
        \gdef\@englishkeywords{#1}%
        \iflanguage{english}{
                \begin{otherlanguage}{brazilian}
        }{
                \begin{otherlanguage}{english}
        }
        %\begin{center}%
        %    \textbf{#1}%
        %    \vspace{12pt}
        %\end{center}
        \samepagechapter*{\abstractname}\setlength{\parindent}{0pt}
}{%
  \vspace{12pt}

  \noindent\textbf{\keywordsname:} \@englishkeywords.
\end{otherlanguage}
}

\newenvironment{oldenglishabstract}[2]{%
        \if@openright\cleardoublepage\else\clearpage\fi%
        \gdef\@englishkeywords{#2}%
        \iflanguage{english}{
                \begin{otherlanguage}{brazilian}
        }{
                \begin{otherlanguage}{english}
        }
        \begin{center}%
            \textbf{#1}%
            \vspace{12pt}
        \end{center}
        \samepagechapter*{\abstractname}\setlength{\parindent}{0pt}
}{%
  \vspace{12pt}

  \noindent\textbf{\keywordsname:} \@englishkeywords.
\end{otherlanguage}
}


%==============================================================================
% Formatao dos captulos.
% Os comandos \@chapter e \@schapter so redefinidos para que a
% numerao de pginas seja correta (deve aparecer somente a partir do
% primeiro captulo do texto, mas no nas pginas iniciais de
% captulos).
% Os comandos \@makechapterhead e \@makeschapterhead fazem a
% formatao dos ttulos propriamente ditos.
%==============================================================================
\newcounter{schapter}
\newcommand{\ii@chapterfont}{\@setfontsize\Large{12}{18}}
\def\@chapapp{}
\def\@chapappextra{}
\def\@chappositioning{\noindent}
\def\@chapter[#1]#2{%
        \xdef\Hy@chapapp{CHAPTER}%
        \gdef\theHchapter{\thechapter}%
        \refstepcounter{chapter}%
        \addcontentsline{toc}{chapter}{\@chapapp\thechapter~\@chapappextra#1}%
        \addtocontents{lof}{\protect\addvspace{10\p@}}%
        \addtocontents{lot}{\protect\addvspace{10\p@}}%
        \addtocontents{lol}{\protect\addvspace{10\p@}}%
        \pagestyle{iiufrgs}\let\ps@plain\ps@iiufrgs%
        \@makechapterhead{#2}{\@chappositioning}\@afterheading

}

\def\@makechapterhead#1#2{%
        %\vspace*{90pt}
        %\vspace{12pt}
        \reset@font{#2{\ii@chapterfont\textbf{\@chapapp\thechapter\hphantom{~}\@chapappextra\MakeUppercase{#1}}\par}}
        \addvspace{\baselineskip}
        \noindent
        %\par
}
\def\@schapter#1{%
        \xdef\Hy@chapapp{SCHAPTER}%
        \refstepcounter{schapter}%
        \if@aftertoc%
            \hyperdef{SCHAPTER}{\theschapter}{}%
            \@makeschapterhead{#1}\@afterheading%
            \addcontentsline{toc}{chapter}{\@chapapp\xspace{}\@chapappextra#1}%
        \else%
            \pdfbookmark[0]{#1}{MUTESCHAPTER.\theschapter}%
            \@makeschapterhead{#1}\@afterheading%
        \fi%
        \addtocontents{lof}{\protect\addvspace{10\p@}}%
        \addtocontents{lot}{\protect\addvspace{10\p@}}%
}
\def\@makeschapterhead#1{%
        %\vspace*{90pt}
        \reset@font\centerline{\ii@chapterfont\textbf{\MakeUppercase{\@chapapp\xspace{}\@chapappextra#1}}}
        \addvspace{18pt}
}
\renewcommand{\appendix}[1][\appendixname]{
    \setcounter{chapter}{0}%
    \renewcommand{\thechapter}{\Alph{chapter}}%
    \gdef\@chapapp{\texorpdfstring{\MakeUppercase{#1}}{#1}\space}%
    \gdef\@chapappextra{---\space}%
    \gdef\@chappositioning{\centering}
}
\newcommand{\annex}{\appendix[\annexname]}

%==============================================================================
% Formatação das seções
%==============================================================================
\setcounter{secnumdepth}{5}
\renewcommand{\@seccntformat}[1]{\csname the#1\endcsname\ }

% \renewcommand{\section}{%
%         \@startsection{section}{2}{0pt}{18pt}{18pt}{\reset@font\normalsize\bfseries}
% }
%\titleformat*{\section}{\reset@font\normalsize\bfseries}
\titleformat{\section}[hang]{\bfseries}{\thesection~}{0pt}{}
\titlespacing\section{0pt}{1.5\baselineskip}{\baselineskip}
\titleformat*{\subsection}{\reset@font\normalsize\bfseries}
\titlespacing\subsection{0pt}{1.5\baselineskip}{\baselineskip}
\titleformat*{\subsubsection}{\reset@font\normalsize\itshape}
\titlespacing\subsubsection{0pt}{1\baselineskip}{0.5\baselineskip}
\titleformat*{\paragraph}{\reset@font\normalsize}
\titlespacing\paragraph{0pt}{1\baselineskip}{0.5\baselineskip}
% \renewcommand{\subsection}{%
%         \@startsection{subsection}{3}{0pt}{18pt}{18pt}{\reset@font\bfseries}
% }
% \renewcommand{\subsubsection}{%
%         \@startsection{subsubsection}{4}{0pt}{18pt}{18pt}{\reset@font\itshape}
% }
% \renewcommand{\paragraph}{%
%         \@startsection{paragraph}{5}{0pt}{18pt}{18pt}{\reset@font}
% }

%==============================================================================
% Redefinição do formato de citações longas
%==============================================================================
\renewenvironment{quote}{%
        \setstretch{1}%
        \small%
        \begin{list}{}{\setlength{\leftmargin}{40mm}\item\relax}
        \fontsize{10bp}{12bp}\selectfont%
}{%
        \end{list}
}


%==============================================================================
% Ajuste do espaamento entre itens em 'enumerate', 'itemize' e 'description'
%==============================================================================
\renewenvironment{enumerate}{%
  \begin{list}{\arabic{enumi}.}{\topsep=6pt\itemsep=2pt\parsep=0pt\partopsep=0pt\usecounter{enumi}}%
}{\end{list}}

\renewenvironment{itemize}{%
  \begin{list}{\bfseries\upshape $\bullet$}{\topsep=6pt\itemsep=2pt\parsep=0pt\partopsep=0pt}%
}{\end{list}}

\renewenvironment{description}{
  \begin{list}{}{\topsep=6pt\itemsep=2pt\parsep=0pt\partopsep=0pt \labelwidth\z@ \itemindent-\leftmargin \let\makelabel\descriptionlabel}
}{\end{list}}

%==============================================================================
% Ajuste das legendas das figuras e tabelas
%==============================================================================
%\RequirePackage{float}
%\floatstyle{plaintop}
%\restylefloat{figure}
%\restylefloat{table}

%\captiondelim{ -- }																												% separador entre no nome Figura e o seu nome
\captionsetup[figure]{justification=raggedright,singlelinecheck=false}    % ttulo das figuras alinhado  esquerda
\captionsetup[table]{justification=centering,singlelinecheck=false}       % ttulo das tabelas centralizado
%\setlength{\abovecaptionskip}{0pt}
%\setlength{\belowcaptionskip}{0pt}
%\setlength{\belowlegendskip}{0pt}

%\captiontitlefont{\small}
\newcommand{\fonte}[1]{\legend{{\small Fonte: #1}}}                       % definio da fonte de figuras e tabelas com fonte menor

%==============================================================
% ajustes manual de normalizao (Csar Huegel - 12/2016)
% separador caption label 
% numerao contnua para figuras, tabelas e equaes
%==============================================================
\DeclareCaptionLabelSeparator{traco}{ -- }
\captionsetup[figure]{labelformat=simple, labelsep=traco}
\captionsetup[table]{labelformat=simple, labelsep=traco}
\usepackage{chngcntr}
\counterwithout{figure}{chapter}
\renewcommand{\thefigure}{\arabic{figure}}
\counterwithout{table}{chapter}
\renewcommand{\thechapter}{\arabic{chapter}}
\counterwithout{equation}{chapter}
\renewcommand{\theequation}{\arabic{equation}}


\usepackage[hang,flushmargin]{footmisc} % remove indentao nas notas de rodap (Csar Huegel - 12/2016)



